if RequiredScript == "lib/managers/menumanager" then

	_G.CompassStandalone = {}
	CompassStandalone._save_path = SavePath .. "CompassStandaloneSettings.txt"
	CompassStandalone._path = ModPath or "mods/Compass Standalone/"
	
	CompassStandalone.settings = {
		enabled = true,
		panel_compass_alpha = 1,
		panel_compass_y = 64,
		compass_color = "2EA1FF", --halo reach blue
		compass_color_bg = "2EA1FF", 
		compass_bg_blend_mode = "add" --(non-exhaustive) options include "add", "sub", or "multiply" 
	}

	function CompassStandalone:IsEnabled()
		return self.settings.enabled
	end

	function CompassStandalone:Update(t,dt)
		local player = managers.player:local_player()
		if player then 
			local rotlook = player:movement():m_head_rot()
			self:_set_compass(rotlook)
		end
	end
	
	function CompassStandalone:_create_khud_compass(hud_panel)
		local compass_color = Color(self.settings.compass_color)
		local compass_color_bg = Color(self.settings.compass_color_bg)
		local function get_cardinal(angle)
			angle = tostring(angle)
			local cardinal = {
				["0"] = "N",
				["45"] = "NW",
				["90"] = "W",
				["135"] = "SW",
				["180"] = "S",
				["225"] = "SE",
				["270"] = "E",
				["315"] = "NE",
				["360"] = "N"
			}
			return cardinal[angle] or angle
		end
		
		local mul = 2
		local degrees = 360
		local compass_w = hud_panel:w() * mul
		local compass_h = 16
		local compass_y = compass_h * 2
		
		local tick_margin = compass_w / (degrees * mul)

		local compass_panel = hud_panel:panel({
			name = "compass_panel",
			visible = true,
			layer = 0,
			x = 0,
			y = compass_y,
			w = compass_w
		})
		
		local compass_strip = compass_panel:panel({
			name = "compass_strip",
			layer = 0,
			x = (hud_panel:w() - compass_w) / 2,
	--		y = compass_y,
			h = compass_h * 2
		})
		
		local ticks = math.floor(compass_w / tick_margin)
		
		local ammo_font = tweak_data.hud_players.ammo_font
		
		local alpha = 0.5
		for i = 0, ticks, 1 do 
			if (i % (degrees / 4)) == 0 then --90
				alpha = 1
				local newtick = compass_strip:text({
					name = "direction_" .. tostring(i),
					color = compass_color,
					layer = 2,
					font = ammo_font,
					font_size = compass_h,
					x = (i * tick_margin),
					vertical = "bottom",
					alpha = alpha,
					text = get_cardinal(i % degrees)
				})
				local _,_,text_w,_ = newtick:text_rect()
				newtick:move(-text_w * 0.25)
			elseif (i % (degrees / 8)) == 0 then --45
				alpha = 0.75
				local newtick = compass_strip:text({
					name = "direction_" .. tostring(i),
					color = compass_color,
					layer = 2,
					font = ammo_font,
					font_size = compass_h * 0.75,
					x = (i * tick_margin),
					vertical = "bottom",
					alpha = alpha,
					text = get_cardinal(i % degrees)
				})
				local _,_,text_w,_ = newtick:text_rect()
				newtick:move(-text_w * 0.25)
			elseif (i % (degrees / 24)) == 0 then --15
				alpha = 0.5
				compass_strip:text({
					name = "direction_" .. tostring(i),
					color = compass_color,
					layer = 2,
					font = ammo_font,
					font_size = compass_h * 0.5,
					x = (i * tick_margin) + 4,
					alpha = alpha,
					text = get_cardinal(i % degrees)
				})
			else
				alpha = 0.25
			end
			compass_strip:text({
				name = "tick_" .. tostring(i),
				color = compass_color,
				layer = 1,
				font = ammo_font,
				font_size = compass_h,
				x = i * tick_margin,
				alpha = alpha,
				text = "|"
			})
		end
		local backdrop = compass_panel:rect({
			name = "backdrop",
			layer = 0,
			blend_mode = "sub",
			color = Color.black:with_alpha(0.5),
		})
		
		local shine = compass_panel:gradient({
			name = "khud_compass_shine",
			layer = 1,
			blend_mode = self.settings.compass_bg_blend_mode or "add",
			w = hud_panel:w(),
			h = compass_h,
			valign = "grow",
			gradient_points = {
				0,
				Color(0,1,1,1), --argb
				0.3,
				compass_color_bg:with_alpha(0),
				0.5,
				compass_color_bg:with_alpha(0.2),
				0.8,
				compass_color_bg:with_alpha(0),
				1,
				Color(0,1,1,1)
			}
		})
		local debug_compass = compass_panel:rect({
			name = "debug_compass",
			visible = false,
			color = Color.red:with_alpha(0.1)
		})
		self._panel = compass_panel
		
		return compass_panel
	end

	function CompassStandalone:_set_compass(veclook)
		local panel = self._panel
		if panel and self:IsEnabled() then 
			local yaw = veclook:yaw()
			local compass = panel:child("compass_strip")
			local compass_yaw = (0.5 + (math.rad(yaw * 0.25) / math.pi)) - 0.75
			compass:set_x(compass_yaw * panel:w())
		end
	end

	function CompassStandalone:_layout_compass_panel(params)
		local compass = self._panel
		if compass and alive(compass) then 
		
			params = params or {}
			local settings = self.settings
			
			local strip = compass:child("compass_strip")

			local alpha = params.alpha or settings.panel_compass_alpha or 1
			local y = params.y or settings.panel_compass_y or 64
			
			compass:set_alpha(alpha)
			compass:set_visible(self:IsEnabled())
			
--			compass:set_x(x)
			compass:set_y(y)
--			compass:set_w(1000)
			
		end
	end

	function CompassStandalone:Load()
		local file = io.open(self._save_path, "r")
		if (file) then
			for k, v in pairs(json.decode(file:read("*all"))) do
				self.settings[k] = v
			end
		else
			self:Save() --create data in case there's no mod save data
		end
		return self.settings
	end

	function CompassStandalone:Save()
		local file = io.open(self._save_path,"w+")
		if file then
			file:write(json.encode(self.settings))
			file:close()
		end
	end

	Hooks:Add("MenuManagerInitialize", "compassstandalone_menumanagerinit", function(menu_manager)

		MenuCallbackHandler.callback_compassstandalone_onclosedmenu = function(self)
			CompassStandalone:Save()
		end
		MenuCallbackHandler.callback_compassstandalone_set_enabled = function(self,item)
			local value = item:value() == "on"
			CompassStandalone.settings.enabled = value
			if managers.hud then
				if value then 
					managers.hud:add_updator("_update_hud_compass_standalone",callback(CompassStandalone,CompassStandalone,"Update"))
				else
					managers.hud:remove_updator("_update_hud_compass_standalone")
				end
			end
			CompassStandalone:_layout_compass_panel()
		end
		
		MenuCallbackHandler.callback_compassstandalone_set_alpha = function(self,item)
			local value = tonumber(item:value())
			CompassStandalone.settings.panel_compass_alpha = value
			CompassStandalone:_layout_compass_panel()
		end	
		
		MenuCallbackHandler.callback_compassstandalone_set_y = function(self,item)
			local value = tonumber(item:value())
			CompassStandalone.settings.panel_compass_y = value
			CompassStandalone:_layout_compass_panel()
		end	
		
		
		MenuHelper:LoadFromJsonFile(CompassStandalone._path .. "options.txt", CompassStandalone, CompassStandalone.settings)

		CompassStandalone:Load()
	end)

	Hooks:Add("LocalizationManagerPostInit", "compass_standalone_localization", function( loc )
		loc:add_localized_strings({
			compass_standalone_title = "Compass Standalone",
			compass_standalone_desc = "KineticHUD's Compass Standalone",
			compass_standalone_enabled_title = "Enabled",
			compass_standalone_enabled_desc = "Enable HUD Compass Panel",
			compass_standalone_alpha_title = "Opacity",
			compass_standalone_alpha_desc = "Higher numbers are more visible",
			compass_standalone_y_title = "Vertical Position",
			compass_standalone_y_desc = "HUD Compass Panel Y Position"
		})
	end)
	
elseif RequiredScript == "lib/managers/hudmanagerpd2" then 

	Hooks:PostHook(HUDManager,"_create_assault_corner","compass_standalone_init_hud",function(self)
		local hud = managers.hud:script(PlayerBase.PLAYER_INFO_HUD_FULLSCREEN_PD2) --or _hud
		if hud then 
			CompassStandalone:_create_khud_compass(hud.panel)
			CompassStandalone:_layout_compass_panel()
			if CompassStandalone:IsEnabled() then 
				self:add_updator("_update_hud_compass_standalone",callback(CompassStandalone,CompassStandalone,"Update"))
			end
		end
	end)
	
end